import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Text,
  Code,
  Box,
  Pane,
  Content
} from '../components'

const quickBrownFox = 'The quick brown fox jumps over the lazy dog'

export default function textStory (module) {
  storiesOf('Text', module)
    .add('usage', () => (
      <App flex>
        <Pane white padding={10}>
          <Content markdown>
{`
# Text

The Text component is a \`p\` by default. Implements Box.

* Display, body, caps and mono can't be mixed

\`\`\`
<Text textStyle='display1'>Display (1)</Text>
<Text textStyle='display2'>Display 2</Text>
<Text textStyle='display3'>Display 3</Text>
<Text textStyle='display4'>Display 4</Text>
<Text textStyle='body1'>Body (1)</Text>
<Text textStyle='body2'>Body 2</Text>
<Text textStyle='mono'>Mono</Text>
<Text textStyle='caps1'>Caps 1</Text>
<Text textStyle='caps2'>Caps 2</Text>
\`\`\`

`}
          </Content>
          <Text textStyle='display1'>Display (1)</Text>
          <Text textStyle='display2'>Display 2</Text>
          <Text textStyle='display3'>Display 3</Text>
          <Text textStyle='display4'>Display 4</Text>
          <Text textStyle='body1'>Body (1)</Text>
          <Text textStyle='body2'>Body 2</Text>
          <Text textStyle='mono'>Mono</Text>
          <Text textStyle='caps1'>Caps 1</Text>
          <Text textStyle='caps2'>Caps 2</Text>
          <Content markdown>
{`

## Text Styles API

Listed as a reference. Is not unique to \`<Text />\`, but is implemented on Box.

prop | type | description
-----|------|------------
\`textStyle\` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('Display (1) Text', () => (
      <App><Text textStyle='display1'>{quickBrownFox}</Text></App>
    ))
    .add('Display 2 Text', () => (
      <App><Text textStyle='display2'>{quickBrownFox}</Text></App>
    ))
    .add('Display 3 Text', () => (
      <App><Text textStyle='display3'>{quickBrownFox}</Text></App>
    ))
    .add('Display 4 Text', () => (
      <App><Text textStyle='display4'>{quickBrownFox}</Text></App>
    ))
    .add('Body (1) Text', () => (
      <App><Text textStyle='body1'>{quickBrownFox}</Text></App>
    ))
    .add('Body 2 Text', () => (
      <App><Text textStyle='body2'>{quickBrownFox}</Text></App>
    ))
    .add('Mono Text', () => (
      <App><Text textStyle='mono'>{quickBrownFox}</Text></App>
    ))
    .add('Truncate Text', () => (
      <App>
        <div style={{ width: 240 }}>
          <Text textStyle='body1' truncate>Truncate Text when it gets too long lorem ipsum</Text>
        </div>
      </App>
    ))
    .add('Muted (1) Text', () => (
      <App><Text muted>Soft Mute your text: <Code>{'<Text muted>...</Text>'}</Code></Text></App>
    ))
    .add('Muted 2 Text', () => (
      <App><Text muted={2}>Mute your text even more: <Code>{'<Text muted={2}>...</Text>'}</Code></Text></App>
    ))
}
